@@ -1,13 +1,15 @@
 from pyais.messages import NMEAMessage, AISMessage
 from pyais.stream import TCPStream, FileReaderStream, IterMessages
 from pyais.decode import decode_msg
-
+from pyais.encode import encode_dict, encode_payload
 
 __license__ = 'MIT'
-__version__ = '1.6.3'
+__version__ = '1.7.0'
 
 __all__ = (
     'decode_msg',
+    'encode_dict',
+    'encode_payload',
     'NMEAMessage',
     'AISMessage',
     'TCPStream',
